<?php
global $wpdb;

if (!class_exists('WP_List_Table')) {
	require_once ABSPATH . 'wp-admin/includes/class-wp-list-table.php';
}

class ARFeedly extends WP_List_Table {
	private $data = [];
	/**
	 * Constructor, we override the parent to pass our own arguments
	 * We usually focus on three parameters: singular and plural labels, as well as whether the class supports AJAX.
	 */

	public function __construct($data) {
		parent::__construct(array(
			'singular' => 'content', //Singular label
			'plural' => 'contents', //plural label, also this well be one of the table css class
			'ajax' => false, //We won't support Ajax for this table
		));

		add_action('admin_head', array(&$this, 'admin_header'));
		$this->data = $data;
	}

	public function extra_tablenav($which) {
		if ($which == "top") {
		}
		if ($which == "bottom") {
		}
	}

	public function column_default($item, $column_name) {
		return $item[$column_name];
	}

	public function column_cb($item) {
		return sprintf(
			'<input type="checkbox" name="%1$s[]" value="%2$s" />',
			/*$1%s*/$this->_args['singular'], //Let's simply repurpose the table's singular label ("movie")
			/*$2%s*/ $item['feedId']//The value of the checkbox should be the record's id
		);
	}

	public function column_lastUpdated($item) {
		return date('Y-m-d', $item['lastUpdated'] / 1000);
	}

	public function column_website($item) {
		return substr($item['feedId'], 5);
	}

	public function column_subscribers($item) {
		return number_format($item['subscribers']);
	}

	public function column_iconUrl($item) {
		return "<img src='${item['iconUrl']}' style='max-width: 50px; max-height: 50px;' />";
	}

	public function get_columns() {
		return $columns = array(
			'cb' => '<input type="checkbox" />',
			'title' => 'Title',
			'website' => 'Feed Url',
			'lastUpdated' => 'Last Updated',
			'contentType' => 'Content Type',
			'language' => 'Language',
			'velocity' => 'Velocity',
			'subscribers' => 'Subscribers',
			'iconUrl' => 'Visual URL',
			'description' => 'Description',
		);
	}

	public function get_sortable_columns() {
		$sortable_columns = array(
			'title' => array('title', false),
			'website' => array('website', false),
			'lastUpdated' => array('last_updated', false),
			'contentType' => array('content_type', false),
			'language' => array('language', false),
			'velocity' => array('velocity', false),
			'subscribers' => array('subscribers', false),
			'iconUrl' => array('iconUrl', false),
		);
		return $sortable_columns;
	}

	public function get_bulk_actions()
	{
		$actions = array(
			'store' => 'Save'
		);
		return $actions;
	}

	public function process_bulk_action()
	{
		global $wpdb;
		$table_name = $wpdb->prefix ."arp_feeds";

		if ('store' === $this->current_action()) {
		}
	}

	public function prepare_items() {

		/**
		 * First, lets decide how many records per page to show
		 */
		$per_page = 50;

		/**
		 * REQUIRED. Now we need to define our column headers. This includes a complete
		 * array of columns to be displayed (slugs & titles), a list of columns
		 * to keep hidden, and a list of columns that are sortable. Each of these
		 * can be defined in another method (as we've done here) before being
		 * used to build the value for our _column_headers property.
		 */
		$columns = $this->get_columns();
		$hidden = array();
		$sortable = $this->get_sortable_columns();

		/**
		 * REQUIRED. Finally, we build an array to be used by the class for column
		 * headers. The $this->_column_headers property takes an array which contains
		 * 3 other arrays. One for all columns, one for hidden columns, and one
		 * for sortable columns.
		 */
		$this->_column_headers = array($columns, $hidden, $sortable);

		$this->process_bulk_action();

		/**
		 * Instead of querying a database, we're going to fetch the example data
		 * property we created for use in this plugin. This makes this example
		 * package slightly different than one you might build on your own. In
		 * this example, we'll be using array manipulation to sort and paginate
		 * our data. In a real-world implementation, you will probably want to
		 * use sort and pagination data to build a custom query instead, as you'll
		 * be able to use your precisely-queried data immediately.
		 */
		global $wpdb;
		$wpdb->show_errors();
		$data = $this->data;

		/**
		 * This checks for sorting input and sorts the data in our array accordingly.
		 *
		 * In a real-world situation involving a database, you would probably want
		 * to handle sorting by passing the 'orderby' and 'order' values directly
		 * to a custom query. The returned data will be pre-sorted, and this array
		 * sorting technique would be unnecessary.
		 */

		usort($data, 'ar_usort_reorder');

		$current_page = $this->get_pagenum();

		/**
		 * REQUIRED for pagination. Let's check how many items are in our data array.
		 * In real-world use, this would be the total number of items in your database,
		 * without filtering. We'll need this later, so you should always include it
		 * in your own package classes.
		 */
		$total_items = count($data);

		/**
		 * The WP_List_Table class does not handle pagination for us, so we need
		 * to ensure that the data is trimmed to only the current page. We can use
		 * array_slice() to
		 */
		$data = array_slice($data, (($current_page - 1) * $per_page), $per_page);

		/**
		 * REQUIRED. Now we can add our *sorted* data to the items property, where
		 * it can be used by the rest of the class.
		 */
		$this->items = $data;

		/**
		 * REQUIRED. We also have to register our pagination options & calculations.
		 */
		$this->set_pagination_args(array(
			'total_items' => $total_items, //WE have to calculate the total number of items
			'per_page' => $per_page, //WE have to determine how many items to show on a page
			'total_pages' => ceil($total_items / $per_page), //WE have to calculate the total number of pages
		));
	}
}
